| GPModel_shared_params | R Documentation |
GPModel, gpb.cv, and gpboostDocumentation for parameters shared by GPModel, gpb.cv, and gpboost
GPModel_shared_params(likelihood = NULL, likelihood_additional_param = NULL,
group_data = NULL, group_rand_coef_data = NULL,
ind_effect_group_rand_coef = NULL,
drop_intercept_group_rand_effect = NULL, gp_coords = NULL,
gp_rand_coef_data = NULL, cov_function = NULL, cov_fct_shape = NULL,
gp_approx = NULL, num_parallel_threads = NULL, GPU_use = NULL,
cov_fct_taper_range = NULL, cov_fct_taper_shape = NULL,
num_neighbors = NULL, vecchia_ordering = NULL,
ind_points_selection = NULL, num_ind_points = NULL,
cover_tree_radius = NULL, matrix_inversion_method = NULL, seed = NULL,
vecchia_pred_type = NULL, num_neighbors_pred = NULL,
cg_delta_conv_pred = NULL, nsim_var_pred = NULL,
rank_pred_approx_matrix_lanczos = NULL, cluster_ids = NULL,
weights = NULL, likelihood_learning_rate = NULL, free_raw_data = NULL,
y = NULL, X = NULL, params = NULL, offset = NULL,
fixed_effects = NULL, group_data_pred = NULL,
group_rand_coef_data_pred = NULL, gp_coords_pred = NULL,
gp_rand_coef_data_pred = NULL, cluster_ids_pred = NULL, X_pred = NULL,
predict_cov_mat = NULL, predict_var = NULL, sample_posterior = NULL,
sample_prior = NULL, num_post_samples = NULL, num_prior_samples = NULL,
std_err = NULL, vecchia_approx = NULL, num_data = NULL)
likelihood |
A
|
likelihood_additional_param |
A
|
group_data |
A |
group_rand_coef_data |
A |
ind_effect_group_rand_coef |
A |
drop_intercept_group_rand_effect |
A |
gp_coords |
A |
gp_rand_coef_data |
A |
cov_function |
A
|
cov_fct_shape |
A |
gp_approx |
A
|
num_parallel_threads |
An |
GPU_use |
A |
cov_fct_taper_range |
A |
cov_fct_taper_shape |
A |
num_neighbors |
An
Note: for prediction, the number of neighbors can be set through the 'num_neighbors_pred' parameter in the 'set_prediction_data' function. By default, num_neighbors_pred = 2 * num_neighbors. Further, the type of Vecchia approximation used for making predictions is set through the 'vecchia_pred_type' parameter in the 'set_prediction_data' function |
vecchia_ordering |
A
|
ind_points_selection |
A
|
num_ind_points |
An
|
cover_tree_radius |
A |
matrix_inversion_method |
A
|
seed |
An |
vecchia_pred_type |
A
|
num_neighbors_pred |
an |
cg_delta_conv_pred |
a |
nsim_var_pred |
an
|
rank_pred_approx_matrix_lanczos |
an |
cluster_ids |
A |
weights |
A |
likelihood_learning_rate |
A |
free_raw_data |
A |
y |
A |
X |
A |
params |
A
|
offset |
A |
fixed_effects |
This is discontinued. Use the renamed equivalent argument |
group_data_pred |
A |
group_rand_coef_data_pred |
A |
gp_coords_pred |
A |
gp_rand_coef_data_pred |
A |
cluster_ids_pred |
A |
X_pred |
A |
predict_cov_mat |
A |
predict_var |
A |
sample_posterior |
A |
sample_prior |
A |
num_post_samples |
A |
num_prior_samples |
A |
std_err |
A |
vecchia_approx |
Discontinued. Use the argument |
num_data |
A |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.