X: Predictor variable data for example data for the GPBoost...

XR Documentation

Predictor variable data for example data for the GPBoost package

Description

A matrix with covariate data for the example data of the GPBoost package

Usage

data(GPBoost_data)

gpboost documentation built on Aug. 20, 2026, 1:06 a.m.