- object
a GPModel
- predict_response
A boolean. If TRUE, the response variable (label)
is predicted, otherwise the latent random effects
- predict_var
A boolean. If TRUE, the (posterior)
predictive variances are calculated
- predict_cov_mat
A boolean. If TRUE, the (posterior)
predictive covariance is calculated in addition to the (posterior) predictive mean
- sample_posterior
A boolean. If TRUE, samples from the posterior are drawn
- sample_prior
A boolean. If TRUE, samples from the prior are drawn
- num_post_samples
A numeric with the number of posterior samples to draw if 'sample_posterior=TRUE'
- num_prior_samples
A numeric with the number of prior samples to draw if 'sample_prior=TRUE'
- y
Observed data (can be NULL, e.g. when the model has been estimated
already and the same data is used for making predictions)
- cov_pars
A vector containing covariance parameters which are used if the
GPModel has not been trained or if predictions should be made for other
parameters than the trained ones
- group_data_pred
A vector or matrix with elements being group levels
for which predictions are made (if there are grouped random effects in the GPModel)
- group_rand_coef_data_pred
A vector or matrix with covariate data
for grouped random coefficients (if there are some in the GPModel)
- gp_coords_pred
A matrix with prediction coordinates (=features) for
Gaussian process (if there is a GP in the GPModel)
- gp_rand_coef_data_pred
A vector or matrix with covariate data for
Gaussian process random coefficients (if there are some in the GPModel)
- cluster_ids_pred
A vector with elements indicating the realizations of
random effects / Gaussian processes for which predictions are made
(set to NULL if you have not specified this when creating the GPModel)
- X_pred
A matrix with prediction covariate data for the
fixed effects linear regression term (if there is one in the GPModel)
- use_saved_data
A boolean. If TRUE, predictions are done using
a priory set data via the function '$set_prediction_data' (this option is not used by users directly)
- offset
A numeric vector with
additional fixed effects contributions that are added to the linear predictor (= offset).
The length of this vector needs to equal the number of training data points times the number of fixed-effect sets.
- offset_pred
A numeric vector with
additional fixed effects contributions that are added to the linear predictor for the prediction points (= offset).
The length of this vector needs to equal the number of prediction points times the number of fixed-effect sets.
- fixed_effects
This is discontinued. Use the renamed equivalent argument offset instead
- fixed_effects_pred
This is discontinued. Use the renamed equivalent argument offset_pred instead
- vecchia_pred_type
A string specifying the type of Vecchia approximation used for making predictions.
This is discontinued here. Use the function 'set_prediction_data' to specify this
- num_neighbors_pred
an integer specifying the number of neighbors for making predictions.
This is discontinued here. Use the function 'set_prediction_data' to specify this
- ...
(not used, ignore this, simply here that there is no CRAN warning)