group_data_test: Test grouping data for example data for the GPBoost package

group_data_testR Documentation

Test grouping data for example data for the GPBoost package

Description

A matrix with categorical grouping variables for predictions for the example data of the GPBoost package

Usage

data(GPBoost_data)

gpboost documentation built on June 25, 2026, 1:07 a.m.